pub enum CbResult {
Stop,
Ok,
}Expand description
The result of processing a batch of netlink responses.
Variants
Stop
Everything went fine and this batch is finished processing.
Ok
Everything went fine, but we expect more messages to come back from the kernel for this batch.